/// <reference path="alf.d.ts" />
/// <reference path="yui.d.ts" />
/// <reference path="knockout-2.2.d.ts" />

class DocList
{
    folderTable: Y.DataTable;
    
    constructor ()
    { 
    }

    getDocListSuccess(data: any)
    {
        for (var i = 0; i < data.items.length; i++) 
        {
            var props = data.items[i].node.properties;
            var name = props["cm:name"];
            var title = props["cm:title"];
            var created = props["cm:created"];
            var modified = props["cm:modified"];
            var row = { 'name': name, 'title': title, 'created': created.value, 'modified': modified.value };
            this.folderTable.addRow(row);
        }
    }

    getDocListError(err:any)
    {
        //console.log("getDocListError");
    }

    init(htmlId: string) {
        YUI().use("datatable", function (Y) {
            // A table from data with keys that work fine as column names
            this.folderTable = new Y.DataTable({
                columns: [{ key: "name", width: '200px'}, { key: "title", width: '200px'}, { key: "created", width: '200px'}, { key: "modified", width: '200px'}, { key: " ", width: '400'} ],
                data: [
                    //{ name: "test", title: "title", modified: "10/13/2012" }
                ],
                sortable: true
            });
            this.folderTable.render("#" + htmlId);
        });
    }

    loadData(conn: Connection)
    {
        conn.getDocList({
            site: 's1',
            model: 'cm:content',
            container: 'documentLibrary',
            folderPath: '/'
            },
            this.getDocListSuccess,
            this.getDocListError);
    }
}

class RepoTree
{
    treeView: Y.TreeView;

    constructor ()
    {
    }

    init(htmlId: string)
    {
        YUI({gallery: 'gallery-2012.08.29-20-10'}).use("gallery-yui3treeview-ng", function(Y) {
            this.treeView = new Y.TreeView({
                    startCollapsed: false,
                    children: [ {
                        label: "Root",
                        children: [ 
                            {
                                label : "sub 1",
                                children : [
                                    { label: "sub 1-1"},
                                    { label: "sub 1-2"},
                                ]
                            },
                            {
                                label : "sub 2",
                                children : [
                                    { label: "sub 2-1"},
                                    {
                                        label: "sub 2-2",
                                        children: [
                                            { label: "sub 2-2-1" },
                                            { label: "sub 2-2-2" }
                                        ]
                                    },
                                ]
                            }
                        ]
                    }]
            });
            this.treeView.render("#" + htmlId);

            var r = Y.one("#report1");
            this.treeView.on("nodeclick", function(e) {
                var node = e.treenode,
                    label = node.get("label"),
                    isLeaf = node.get("isLeaf"),
                    collapsed = node.get("collapsed");

                r.setContent("");
                r.appendChild("<li>You clicked " + (isLeaf ? "leaf" : "node") + " " + label);
                r.appendChild("<li>Path to root is: " + node.path().join(" > "));
                r.appendChild("<li>State is: " + (collapsed ? "collapsed" : "expanded") );
            });

        });

    }

}

var repoTree = new RepoTree();

var docList = new DocList();

var conn;

class AppViewModel
{
    constructor ()
    {
    }
   
    login()
    {
        conn = AlfJS.createConnection({
            hostname: 'localhost',
            login: 'admin',
            password: 'admin',
            protocol: 'http',
            port: 8080,
            serviceBase: 'alfresco/service/',
            format: 'jsonp', // Optional, the default is 'json', the other option is 'jsonp'
            prefix: '', // Optional, prepend a prefix to the connection URL. Useful if an AJAX proxy is being employed.
        });

        conn.login(this.loginSuccess, this.loginError);
    }

    loginSuccess(data: any)
    {
        var ticket:string = conn.getTicket();   
        // todo: view model shouldn't directly access view part docList 
        docList.loadData(conn);
    }

    loginError(err:any)
    {
        var error = JSON.parse(err.responseText);
    }            
}

window.onload = () => {

    repoTree.init("repotree");

    docList.init("folderlistdatatable");

    var appViewModel = new AppViewModel();
    ko.applyBindings(appViewModel);
};

